==> coming_soon-8.x-3.0.tar.gz: coming_soon/src/Form/ComingSoonAdminForm.php <==
<?php

namespace Drupal\coming_soon\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Manages the Coming Soon admin form.
 */
class ComingSoonAdminForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'coming_soon_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['coming_soon.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('coming_soon.settings');

    $form['coming_soon_heading'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading'),
      '#default_value' => $config->get('coming_soon_heading'),
      '#description' => $this->t("Heading to display in the coming soon page, will default to the site name if omitted."),
    ];

    $form['coming_soon_body'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('coming_soon_body.value'),
      '#format' => $config->get('coming_soon_body.format'),
      '#description' => $this->t("The body text of the page."),
    ];

    $form['coming_soon_notification'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable guests notification'),
      '#description' => $this->t("Enable users to sign up for notification on website launch."),
      '#default_value' => $config->get('coming_soon_notification'),
    ];

    $form['coming_soon_logo'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display logo'),
      '#description' => $this->t("Display the site's default logo."),
      '#default_value' => $config->get('coming_soon_logo'),
    ];

    $form['coming_soon_end_date'] = [
      '#type' => 'date',
      '#title' => $this->t('End date'),
      '#description' => $this->t("When to stop displaying the coming soon page."),
      '#default_value' => $config->get('coming_soon_end_date'),
      '#required' => TRUE,
    ];

    $form['coming_soon_bg'] = [
      '#type' => 'managed_file',
      '#name' => 'coming_soon_bg',
      '#title' => $this->t('Background image'),
      '#default_value' => $config->get('coming_soon_bg'),
      '#description' => t("Background image, if omitted, a default color will be applied."),
      '#upload_location' => 'public://coming_soon/',
    ];

    $form['coming_soon_copyrights'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Copyrights'),
      '#default_value' => $config->get('coming_soon_copyrights'),
      '#description' => $this->t("Copyrights text."),
    ];

    $form['coming_soon_social'] = [
      '#type' => 'fieldset',
      '#title' => $this->t("Social networks"),
    ];

    $form['coming_soon_social']['coming_soon_facebook'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Facebook'),
      '#default_value' => $config->get('coming_soon_facebook'),
      '#description' => $this->t("Facebook link."),
    ];

    $form['coming_soon_social']['coming_soon_twitter'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Twitter'),
      '#default_value' => $config->get('coming_soon_twitter'),
      '#description' => $this->t("Twitter link."),
    ];

    $form['coming_soon_social']['coming_soon_googleplus'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google+'),
      '#default_value' => $config->get('coming_soon_googleplus'),
      '#description' => $this->t("Google+ link."),
    ];

    $form['coming_soon_social']['coming_soon_linkedin'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Linkedin'),
      '#default_value' => $config->get('coming_soon_linkedin'),
      '#description' => $this->t("Linkedin link."),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get submitted values.
    $values = $form_state->getValues();
    $img_value = !empty($values['coming_soon_bg']) ? $values['coming_soon_bg'] : '';

    // Save the configuration.
    $this->config('coming_soon.settings')
      ->set('coming_soon_heading', $values['coming_soon_heading'])
      ->set('coming_soon_body', $values['coming_soon_body'])
      ->set('coming_soon_notification', $values['coming_soon_notification'])
      ->set('coming_soon_logo', $values['coming_soon_logo'])
      ->set('coming_soon_end_date', $values['coming_soon_end_date'])
      ->set('coming_soon_bg', $img_value)
      ->set('coming_soon_copyrights', $values['coming_soon_copyrights'])
      ->set('coming_soon_facebook', $values['coming_soon_facebook'])
      ->set('coming_soon_twitter', $values['coming_soon_twitter'])
      ->set('coming_soon_googleplus', $values['coming_soon_googleplus'])
      ->set('coming_soon_linkedin', $values['coming_soon_linkedin'])
      ->save();

    // Clear cache to allo for the new config to take effect.
    drupal_flush_all_caches();

    // Display success message.
    drupal_set_message($this->t('Coming Soon configuration submitted successfully.'), 'status', TRUE);
  }

}

==> coming_soon-8.x-3.2.tar.gz: coming_soon/src/Form/ComingSoonAdminForm.php <==
<?php

namespace Drupal\coming_soon\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Manages the Coming Soon admin form.
 */
class ComingSoonAdminForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'coming_soon_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['coming_soon.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('coming_soon.settings');

    $form['coming_soon_heading'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Heading'),
      '#default_value' => $config->get('coming_soon_heading'),
      '#description' => $this->t("Heading to display in the coming soon page, will default to the site name if omitted."),
    ];

    $form['coming_soon_body'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('coming_soon_body.value'),
      '#format' => $config->get('coming_soon_body.format'),
      '#description' => $this->t("The body text of the page."),
    ];

    $form['coming_soon_notification'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable guests notification'),
      '#description' => $this->t("Enable users to sign up for notification on website launch."),
      '#default_value' => $config->get('coming_soon_notification'),
    ];

    $form['coming_soon_logo'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display logo'),
      '#description' => $this->t("Display the site's default logo."),
      '#default_value' => $config->get('coming_soon_logo'),
    ];

    $form['coming_soon_end_date'] = [
      '#type' => 'date',
      '#title' => $this->t('End date'),
      '#description' => $this->t("When to stop displaying the coming soon page."),
      '#default_value' => $config->get('coming_soon_end_date'),
    ];

    $form['coming_soon_bg'] = [
      '#type' => 'managed_file',
      '#name' => 'coming_soon_bg',
      '#title' => $this->t('Background image'),
      '#default_value' => $config->get('coming_soon_bg'),
      '#description' => $this->t("Background image, if omitted, a default color will be applied."),
      '#upload_location' => 'public://coming_soon/',
    ];

    $form['coming_soon_copyrights'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Copyrights'),
      '#default_value' => $config->get('coming_soon_copyrights'),
      '#description' => $this->t("Copyrights text."),
    ];

    $form['coming_soon_social'] = [
      '#type' => 'fieldset',
      '#title' => $this->t("Social networks"),
    ];

    $form['coming_soon_social']['coming_soon_facebook'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Facebook'),
      '#default_value' => $config->get('coming_soon_facebook'),
      '#description' => $this->t("Facebook link."),
    ];

    $form['coming_soon_social']['coming_soon_twitter'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Twitter'),
      '#default_value' => $config->get('coming_soon_twitter'),
      '#description' => $this->t("Twitter link."),
    ];

    $form['coming_soon_social']['coming_soon_googleplus'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google+'),
      '#default_value' => $config->get('coming_soon_googleplus'),
      '#description' => $this->t("Google+ link."),
    ];

    $form['coming_soon_social']['coming_soon_linkedin'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Linkedin'),
      '#default_value' => $config->get('coming_soon_linkedin'),
      '#description' => $this->t("Linkedin link."),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get submitted values.
    $values = $form_state->getValues();
    $img_value = !empty($values['coming_soon_bg']) ? $values['coming_soon_bg'] : '';

    // Save the configuration.
    $this->config('coming_soon.settings')
      ->set('coming_soon_heading', $values['coming_soon_heading'])
      ->set('coming_soon_body', $values['coming_soon_body'])
      ->set('coming_soon_notification', $values['coming_soon_notification'])
      ->set('coming_soon_logo', $values['coming_soon_logo'])
      ->set('coming_soon_end_date', $values['coming_soon_end_date'])
      ->set('coming_soon_bg', $img_value)
      ->set('coming_soon_copyrights', $values['coming_soon_copyrights'])
      ->set('coming_soon_facebook', $values['coming_soon_facebook'])
      ->set('coming_soon_twitter', $values['coming_soon_twitter'])
      ->set('coming_soon_googleplus', $values['coming_soon_googleplus'])
      ->set('coming_soon_linkedin', $values['coming_soon_linkedin'])
      ->save();

    // Clear cache to allo for the new config to take effect.
    drupal_flush_all_caches();

    // Display success message.
    drupal_set_message($this->t('Coming Soon configuration submitted successfully.'), 'status', TRUE);
  }

}
